(function (Drupal) {
  function showTab(e, target) {
    e.preventDefault();
    target = target || e.target.closest('.nav-link');

    if (!target) return;

    const targetId = target.getAttribute('id').replace(/^tab-/, 'panel-');
    const targetContent = document.getElementById(targetId);
    if (!targetContent) return;

    const panels = Array.from(targetContent.parentElement.children);
    panels.forEach(function (panel) {
      panel.classList.remove('active');
      panel.setAttribute('aria-hidden', 'true');
      panel.setAttribute('aria-expanded', 'false');
    });

    targetContent.classList.add('active');
    targetContent.setAttribute('aria-hidden', 'false');
    targetContent.setAttribute('aria-expanded', 'true');

    const tabLinks = target.closest('ul').querySelectorAll('.nav-link');
    tabLinks.forEach(function (link) {
      link.classList.remove('active');
      link.setAttribute('aria-selected', 'false');
      link.setAttribute('tabindex', '-1');

      const navItem = link.closest('.nav-item');
      if (navItem) {
        navItem.classList.remove('active');
      }
    });

    target.classList.add('active');
    target.setAttribute('aria-selected', 'true');
    target.setAttribute('tabindex', '0');
    target.focus();

    const activeNavItem = target.closest('.nav-item');
    if (activeNavItem) {
      activeNavItem.classList.add('active');
    }
  }

  document.querySelectorAll('.lb-dyn-tabs .tabs').forEach(function (tabList) {
    tabList.setAttribute('role', 'tablist');

    const tabs = tabList.querySelectorAll('.nav-item');
    tabs.forEach(function (tab) {
      tab.setAttribute('role', 'presentation');
    });

    const links = tabList.querySelectorAll('.nav-link');
    links.forEach(function (link) {
      const id = link.getAttribute('id');
      if (id) {
        link.setAttribute('aria-controls', id.replace(/^tab-/, 'panel-'));
      }

      if (link.classList.contains('active')) {
        link.setAttribute('aria-selected', 'true');
      } else {
        link.setAttribute('aria-selected', 'false');
        link.setAttribute('tabindex', '-1');
      }
    });

    tabList.addEventListener('click', function (e) {
      const link = e.target.closest('.nav-link');
      if (link) {
        showTab(e, link);
      }
    });

    tabList.addEventListener('keyup', function (e) {
      const link = e.target.closest('.nav-link');
      if (!link) return;

      const parent = link.parentElement;
      let moveTo = null;

      if (e.which === 37 || e.keyCode === 37) {
        moveTo =
          parent.previousElementSibling ||
          parent.parentElement.lastElementChild;
      } else if (e.which === 39 || e.keyCode === 39) {
        moveTo =
          parent.nextElementSibling || parent.parentElement.firstElementChild;
      }

      if (moveTo) {
        const newLink = moveTo.querySelector('.nav-link');
        if (newLink) {
          showTab(e, newLink);
        }
      }
    });
  });

  document.querySelectorAll('.tab-content .tab-pane').forEach(function (pane) {
    const id = pane.getAttribute('id');
    if (id) {
      pane.setAttribute('aria-labelledby', id.replace(/^panel-/, 'tab-'));
    }
    if (pane.classList.contains('active')) {
      pane.setAttribute('aria-hidden', 'false');
      pane.setAttribute('aria-expanded', 'true');
    } else {
      pane.setAttribute('aria-hidden', 'true');
      pane.setAttribute('aria-expanded', 'false');
    }
  });
})(Drupal);
